summaryrefslogtreecommitdiffstats
path: root/smb4k/core/smb4ksynchronizer.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-24 13:26:46 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-24 13:26:46 -0600
commite722dbcb9f9763c062336bf3762d2acf72b7bb25 (patch)
tree15409a4dfacbb5f6d42ebe821b9010b1aa8d3769 /smb4k/core/smb4ksynchronizer.h
parent37bfaf4493bf35892747b0e8259843f084ec23b5 (diff)
downloadsmb4k-e722dbcb9f9763c062336bf3762d2acf72b7bb25.tar.gz
smb4k-e722dbcb9f9763c062336bf3762d2acf72b7bb25.zip
Rename KGlobal, KProcess, and KClipboard to avoid conflicts with KDE4
Diffstat (limited to 'smb4k/core/smb4ksynchronizer.h')
-rw-r--r--smb4k/core/smb4ksynchronizer.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/smb4k/core/smb4ksynchronizer.h b/smb4k/core/smb4ksynchronizer.h
index 80ddc55..42d8555 100644
--- a/smb4k/core/smb4ksynchronizer.h
+++ b/smb4k/core/smb4ksynchronizer.h
@@ -126,14 +126,14 @@ class Smb4KSynchronizer : public TQObject
protected slots:
/**
* Reimplemented from KProcess.
*
* @param proc The process that exited
*/
- void slotProcessExited( KProcess *proc );
+ void slotProcessExited( TDEProcess *proc );
/**
* Reimplemented from KProcess.
*
* @param proc The process from which output was received on stdout
*
@@ -141,10 +141,10 @@ class Smb4KSynchronizer : public TQObject
*
* @param len The length of the buffer
*/
- void slotReceivedStdout( KProcess *proc, char *buf, int len );
+ void slotReceivedStdout( TDEProcess *proc, char *buf, int len );
/**
* Reimplemented from KProcess.
*
* @param proc The process from which output was received on stderr
*
@@ -152,11 +152,11 @@ class Smb4KSynchronizer : public TQObject
*
* @param len The length of the buffer
*/
- void slotReceivedStderr( KProcess *proc, char *buf, int len );
+ void slotReceivedStderr( TDEProcess *proc, char *buf, int len );
/**
* This slot is connected to TDEApplication::shutDown() signal.
* It aborts the running KProcess if necessary.
*/
void slotShutdown();
@@ -164,7 +164,7 @@ class Smb4KSynchronizer : public TQObject
/**
* The process object for this class.
*/
- KProcess *m_proc;
+ TDEProcess *m_proc;
/**
* This booian is TRUE if the synchronizer is working and FALSE otherwise.
@@ -126,14 +126,14 @@ class Smb4KSynchronizer : public TQObject
protected slots:
/**
- * Reimplemented from KProcess.
+ * Reimplemented from TDEProcess.
*
* @param proc The process that exited
@@ -126,14 +126,14 @@ class Smb4KSynchronizer : public TQObject
/**
- * Reimplemented from KProcess.
+ * Reimplemented from TDEProcess.
*
* @param proc The process from which output was received on stdout
@@ -141,10 +141,10 @@ class Smb4KSynchronizer : public TQObject
/**
- * Reimplemented from KProcess.
+ * Reimplemented from TDEProcess.
*
* @param proc The process from which output was received on stderr
@@ -152,11 +152,11 @@ class Smb4KSynchronizer : public TQObject
/**
* This slot is connected to TDEApplication::shutDown() signal.
- * It aborts the running KProcess if necessary.
+ * It aborts the running TDEProcess if necessary.
*/
void slotShutdown();